@@ -1,7 +1,7 @@
 package Bencher::Scenario::DamerauLevenshteinModules;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,7 @@ Bencher::Scenario::DamerauLevenshteinModules - Benchmark various modules calcula
 
 =head1 VERSION
 
-This document describes version 0.12 of Bencher::Scenario::DamerauLevenshteinModules (from Perl distribution Bencher-Scenarios-LevenshteinModules), released on 2017-01-13.
+This document describes version 0.13 of Bencher::Scenario::DamerauLevenshteinModules (from Perl distribution Bencher-Scenarios-LevenshteinModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -133,21 +133,21 @@ Benchmark with default options (C<< bencher -m DamerauLevenshteinModules >>):
  +----------------------------------------------+---------+-----------+-----------+------------+---------+---------+
  | participant                                  | dataset | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------------------------+---------+-----------+-----------+------------+---------+---------+
- | Text::Levenshtein::Damerau::PP::pp_edistance | program |     17000 |   57      |     1      |   8e-08 |      20 |
- | Text::Levenshtein::Damerau::PP::pp_edistance | reve    |     38000 |   26.3    |     2.17   | 1.2e-08 |      26 |
- | Text::Levenshtein::Damerau::PP::pp_edistance | euro    |     39002 |   25.639  |     2.2323 | 4.6e-11 |      20 |
- | Text::Levenshtein::Damerau::PP::pp_edistance | foo     |     79000 |   13      |     4.5    | 2.1e-08 |      33 |
- | Text::Levenshtein::Damerau::PP::pp_edistance | a       |    241100 |    4.148  |    13.8    |   1e-10 |      22 |
- | Text::Fuzzy                                  | euro    |    420000 |    2.4    |    24      | 2.5e-09 |      20 |
- | Text::Levenshtein::Damerau::XS::xs_edistance | program |    477000 |    2.1    |    27.3    | 8.3e-10 |      20 |
- | Text::Levenshtein::Damerau::XS::xs_edistance | euro    |    500000 |    2      |    30      | 2.4e-08 |      20 |
- | Text::Fuzzy                                  | program |    620000 |    1.6    |    36      | 2.8e-09 |      29 |
- | Text::Levenshtein::Damerau::XS::xs_edistance | reve    |    626000 |    1.6    |    35.8    | 6.8e-10 |      30 |
- | Text::Fuzzy                                  | reve    |    680000 |    1.5    |    39      | 5.4e-09 |      20 |
- | Text::Levenshtein::Damerau::XS::xs_edistance | foo     |    695700 |    1.437  |    39.82   | 4.6e-11 |      20 |
- | Text::Fuzzy                                  | foo     |    791880 |    1.2628 |    45.324  | 9.4e-12 |      37 |
- | Text::Levenshtein::Damerau::XS::xs_edistance | a       |    991090 |    1.009  |    56.726  | 9.6e-12 |      20 |
- | Text::Fuzzy                                  | a       |   1000000 |    1      |    57      | 1.7e-09 |      20 |
+ | Text::Levenshtein::Damerau::PP::pp_edistance | program |   20000   |   50      |    1       | 1.3e-08 |      20 |
+ | Text::Levenshtein::Damerau::PP::pp_edistance | reve    |   38000   |   26      |    1.9     | 2.7e-08 |      20 |
+ | Text::Levenshtein::Damerau::PP::pp_edistance | euro    |   38863.1 |   25.7313 |    1.94496 | 1.1e-11 |      23 |
+ | Text::Levenshtein::Damerau::PP::pp_edistance | foo     |   71800   |   13.9    |    3.59    |   6e-09 |      25 |
+ | Text::Levenshtein::Damerau::PP::pp_edistance | a       |  220000   |    4.6    |   11       | 6.7e-09 |      20 |
+ | Text::Fuzzy                                  | euro    |  450000   |    2.2    |   23       | 3.3e-09 |      20 |
+ | Text::Levenshtein::Damerau::XS::xs_edistance | program |  471800   |    2.119  |   23.61    | 5.6e-11 |      22 |
+ | Text::Fuzzy                                  | program |  560000   |    1.8    |   28       | 6.4e-09 |      22 |
+ | Text::Levenshtein::Damerau::XS::xs_edistance | reve    |  628900   |    1.5901 |   31.474   | 1.2e-11 |      20 |
+ | Text::Levenshtein::Damerau::XS::xs_edistance | euro    |  678000   |    1.48   |   33.9     | 4.2e-10 |      20 |
+ | Text::Fuzzy                                  | reve    |  729000   |    1.37   |   36.5     | 3.6e-10 |      27 |
+ | Text::Fuzzy                                  | foo     |  775000   |    1.29   |   38.8     | 3.5e-10 |      28 |
+ | Text::Levenshtein::Damerau::XS::xs_edistance | foo     |  780000   |    1.28   |   39.1     | 4.5e-10 |      21 |
+ | Text::Fuzzy                                  | a       |  900000   |    1.1    |   45       | 3.3e-09 |      20 |
+ | Text::Levenshtein::Damerau::XS::xs_edistance | a       | 1000000   |    0.96   |   52       | 1.5e-09 |      25 |
  +----------------------------------------------+---------+-----------+-----------+------------+---------+---------+
 
 
@@ -157,10 +157,10 @@ Benchmark module startup overhead (C<< bencher -m DamerauLevenshteinModules --mo
  +--------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant                    | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +--------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Text::Fuzzy                    | 0.82                         | 4.1                | 16             |       9.6 |                    5.3 |        1   | 2.3e-05 |      20 |
- | Text::Levenshtein::Damerau::PP | 0.98                         | 4.4                | 18             |       8.1 |                    3.8 |        1.2 | 1.1e-05 |      20 |
- | Text::Levenshtein::Damerau::XS | 1.3                          | 4.8                | 18             |       6.3 |                    2   |        1.5 | 2.9e-05 |      21 |
- | perl -e1 (baseline)            | 1.1                          | 4.4                | 18             |       4.3 |                    0   |        2.2 | 1.3e-05 |      20 |
+ | Text::Fuzzy                    | 0.82                         | 4.1                | 16             |       9.8 |                    5.3 |        1   | 1.4e-05 |      20 |
+ | Text::Levenshtein::Damerau::PP | 0.98                         | 4.5                | 18             |       8.4 |                    3.9 |        1.2 | 1.9e-05 |      20 |
+ | Text::Levenshtein::Damerau::XS | 1.3                          | 4.7                | 18             |       6.4 |                    1.9 |        1.5 | 2.2e-05 |      20 |
+ | perl -e1 (baseline)            | 1.1                          | 4.4                | 18             |       4.5 |                    0   |        2.2 | 1.9e-05 |      20 |
  +--------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
