@@ -1,7 +1,7 @@
 package Bencher::Scenario::LevenshteinModules;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -61,7 +61,7 @@ Bencher::Scenario::LevenshteinModules - Benchmark various modules calculating th
 
 =head1 VERSION
 
-This document describes version 0.12 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenarios-LevenshteinModules), released on 2017-01-13.
+This document describes version 0.13 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenarios-LevenshteinModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -175,32 +175,32 @@ Benchmark with default options (C<< bencher -m LevenshteinModules >>):
  +------------------------------------------+---------+-----------+-----------+------------+---------+---------+
  | participant                              | dataset | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +------------------------------------------+---------+-----------+-----------+------------+---------+---------+
- | Text::Levenshtein::fastdistance          | program |     13000 |   77      |      1     | 1.1e-07 |      20 |
- | PERLANCAR::Text::Levenshtein::editdist   | program |     25000 |   41      |      1.9   | 1.6e-07 |      20 |
- | Text::Levenshtein::fastdistance          | reve    |     34000 |   30      |      2.6   | 5.3e-08 |      20 |
- | Text::Levenshtein::fastdistance          | euro    |     40000 |   25      |      3     | 2.6e-08 |      21 |
- | Text::Levenshtein::fastdistance          | foo     |     64000 |   16      |      4.9   | 2.5e-08 |      22 |
- | PERLANCAR::Text::Levenshtein::editdist   | foo     |    110000 |    9.13   |      8.41  | 3.3e-09 |      20 |
- | Text::Levenshtein::fastdistance          | a       |    210000 |    4.8    |     16     | 6.7e-09 |      20 |
- | PERLANCAR::Text::Levenshtein::editdist   | a       |    362000 |    2.76   |     27.8   | 7.3e-10 |      26 |
- | Text::Levenshtein::XS::distance          | program |    520000 |    1.9    |     40     | 2.5e-09 |      20 |
- | Text::Fuzzy                              | euro    |    550000 |    1.8    |     42     | 3.3e-09 |      20 |
- | Text::Levenshtein::XS::distance          | reve    |    670000 |    1.5    |     51     | 1.7e-09 |      20 |
- | Text::Levenshtein::XS::distance          | euro    |    680000 |    1.5    |     52     | 8.1e-09 |      33 |
- | Text::Levenshtein::XS::distance          | foo     |    820100 |    1.219  |     62.92  | 4.5e-11 |      20 |
- | Text::Fuzzy                              | program |    907230 |    1.1023 |     69.602 | 9.1e-12 |      20 |
- | Text::Fuzzy                              | reve    |    991300 |    1.009  |     76.05  | 4.6e-11 |      20 |
- | Text::Fuzzy                              | foo     |   1050000 |    0.95   |     80.8   | 1.1e-10 |      22 |
- | Text::Levenshtein::XS::distance          | a       |   1100000 |    0.93   |     82     | 1.3e-09 |      33 |
- | Text::Fuzzy                              | a       |   1100000 |    0.92   |     83     | 1.7e-09 |      20 |
- | Text::LevenshteinXS::distance            | program |   3040000 |    0.329  |    233     | 1.9e-10 |      27 |
- | Text::Levenshtein::Flexible::levenshtein | program |   4380000 |    0.228  |    336     | 3.5e-11 |      21 |
- | Text::Levenshtein::Flexible::levenshtein | euro    |   4900000 |    0.2    |    380     | 1.4e-09 |      20 |
- | Text::Levenshtein::Flexible::levenshtein | reve    |   6420000 |    0.156  |    492     | 1.1e-10 |      20 |
- | Text::Levenshtein::Flexible::levenshtein | foo     |   7900000 |    0.13   |    600     | 2.1e-10 |      20 |
- | Text::LevenshteinXS::distance            | foo     |   8300000 |    0.12   |    637     | 7.1e-11 |      20 |
- | Text::Levenshtein::Flexible::levenshtein | a       |   9320000 |    0.107  |    715     | 6.5e-11 |      25 |
- | Text::LevenshteinXS::distance            | a       |  11000000 |    0.0909 |    844     | 4.8e-11 |      31 |
+ | Text::Levenshtein::fastdistance          | program |     14000 | 73        |      1     | 5.6e-07 |      20 |
+ | PERLANCAR::Text::Levenshtein::editdist   | program |     28100 | 35.5      |      2.06  | 1.1e-08 |      28 |
+ | Text::Levenshtein::fastdistance          | reve    |     34000 | 30        |      2.5   | 1.1e-07 |      20 |
+ | Text::Levenshtein::fastdistance          | euro    |     39000 | 25        |      2.9   |   5e-08 |      23 |
+ | Text::Levenshtein::fastdistance          | foo     |     70000 | 14        |      5.1   | 2.7e-08 |      20 |
+ | PERLANCAR::Text::Levenshtein::editdist   | foo     |    110000 |  9.2      |      7.9   | 1.3e-08 |      20 |
+ | Text::Levenshtein::fastdistance          | a       |    230000 |  4.4      |     17     | 8.3e-09 |      20 |
+ | PERLANCAR::Text::Levenshtein::editdist   | a       |    400000 |  2.5      |     30     | 2.6e-09 |      20 |
+ | Text::Levenshtein::XS::distance          | program |    513000 |  1.95     |     37.6   | 8.1e-10 |      21 |
+ | Text::Fuzzy                              | euro    |    600000 |  1.7      |     44     | 3.3e-09 |      20 |
+ | Text::Levenshtein::XS::distance          | reve    |    656000 |  1.52     |     48.1   | 1.5e-10 |      31 |
+ | Text::Levenshtein::XS::distance          | euro    |    700000 |  1.4      |     51     | 1.7e-09 |      20 |
+ | Text::Levenshtein::XS::distance          | foo     |    789220 |  1.2671   |     57.804 | 1.1e-11 |      24 |
+ | Text::Fuzzy                              | program |    990000 |  1        |     72     | 1.7e-09 |      20 |
+ | Text::Levenshtein::XS::distance          | a       |   1010000 |  0.993    |     73.7   | 4.1e-10 |      21 |
+ | Text::Fuzzy                              | reve    |   1090000 |  0.914    |     80.2   | 3.2e-10 |      34 |
+ | Text::Fuzzy                              | foo     |   1140000 |  0.879    |     83.3   | 4.1e-10 |      21 |
+ | Text::Fuzzy                              | a       |   1200000 |  0.83     |     88     | 1.6e-09 |      21 |
+ | Text::LevenshteinXS::distance            | program |   3680000 |  0.271    |    270     |   1e-10 |      21 |
+ | Text::Levenshtein::Flexible::levenshtein | program |   4850000 |  0.206    |    355     |   1e-10 |      20 |
+ | Text::Levenshtein::Flexible::levenshtein | euro    |   5175710 |  0.19321  |    379.081 |   0     |      20 |
+ | Text::Levenshtein::Flexible::levenshtein | reve    |   7051530 |  0.141813 |    516.47  |   0     |      24 |
+ | Text::LevenshteinXS::distance            | foo     |   8400000 |  0.12     |    610     | 2.1e-10 |      20 |
+ | Text::Levenshtein::Flexible::levenshtein | foo     |   8600000 |  0.1163   |    629.9   | 9.8e-12 |      22 |
+ | Text::LevenshteinXS::distance            | a       |  10000000 |  0.0998   |    734     | 5.1e-11 |      21 |
+ | Text::Levenshtein::Flexible::levenshtein | a       |  10000000 |  0.0997   |    735     | 5.3e-11 |      20 |
  +------------------------------------------+---------+-----------+-----------+------------+---------+---------+
 
 
@@ -210,13 +210,13 @@ Benchmark module startup overhead (C<< bencher -m LevenshteinModules --module-st
  +------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant                  | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Text::LevenshteinXS          | 1.3                          | 4.8                | 18             |      13   |      8.6               |        1   | 8.3e-05 |      20 |
- | Text::Levenshtein            | 0.98                         | 4.4                | 18             |      11   |      6.6               |        1.2 | 2.6e-05 |      20 |
- | Text::Levenshtein::Flexible  | 1.6                          | 5.1                | 19             |       9.8 |      5.4               |        1.3 | 1.4e-05 |      20 |
- | Text::Fuzzy                  | 0.82                         | 4.1                | 16             |       9.7 |      5.3               |        1.3 | 2.6e-05 |      20 |
- | Text::Levenshtein::XS        | 1.3                          | 4.7                | 18             |       7.9 |      3.5               |        1.6 | 5.8e-05 |      20 |
- | PERLANCAR::Text::Levenshtein | 1.4                          | 4.9                | 19             |       4.8 |      0.399999999999999 |        2.6 | 1.2e-05 |      20 |
- | perl -e1 (baseline)          | 0.85                         | 4.1                | 16             |       4.4 |      0                 |        2.9 | 9.6e-06 |      20 |
+ | Text::LevenshteinXS          | 1.3                          | 4.6                | 18             |      13   |                    8.5 |        1   | 5.9e-05 |      20 |
+ | Text::Levenshtein            | 0.99                         | 4.3                | 18             |      11   |                    6.5 |        1.2 | 4.8e-05 |      20 |
+ | Text::Levenshtein::Flexible  | 1.6                          | 5                  | 19             |      10   |                    5.5 |        1.3 | 1.4e-05 |      20 |
+ | Text::Fuzzy                  | 0.83                         | 4.1                | 16             |      10   |                    5.5 |        1.3 | 5.7e-05 |      20 |
+ | Text::Levenshtein::XS        | 1.3                          | 4.6                | 18             |       8.1 |                    3.6 |        1.6 | 5.1e-05 |      20 |
+ | PERLANCAR::Text::Levenshtein | 1.4                          | 4.8                | 19             |       5   |                    0.5 |        2.6 | 1.4e-05 |      20 |
+ | perl -e1 (baseline)          | 0.85                         | 4.1                | 16             |       4.5 |                    0   |        2.8 | 1.5e-05 |      20 |
  +------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
