@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DamerauLevenshteinModules;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -9,138 +9,138 @@ our $results = [
     [
       {
         dataset     => "program",
-        errors      => 8e-08,
+        errors      => 1.3e-08,
         participant => "Text::Levenshtein::Damerau::PP::pp_edistance",
-        rate        => 17000,
+        rate        => 20000,
         samples     => 20,
-        time        => 57,
+        time        => 50,
         vs_slowest  => 1,
       },
       {
         dataset     => "reve",
-        errors      => 1.2e-08,
+        errors      => 2.7e-08,
         participant => "Text::Levenshtein::Damerau::PP::pp_edistance",
         rate        => 38000,
-        samples     => 26,
-        time        => 26.3,
-        vs_slowest  => 2.17,
+        samples     => 20,
+        time        => 26,
+        vs_slowest  => 1.9,
       },
       {
         dataset     => "euro",
-        errors      => 4.6e-11,
+        errors      => 1.1e-11,
         participant => "Text::Levenshtein::Damerau::PP::pp_edistance",
-        rate        => 39002,
-        samples     => 20,
-        time        => 25.639,
-        vs_slowest  => 2.2323,
+        rate        => 38863.1,
+        samples     => 23,
+        time        => 25.7313,
+        vs_slowest  => 1.94496,
       },
       {
         dataset     => "foo",
-        errors      => 2.1e-08,
+        errors      => 6e-09,
         participant => "Text::Levenshtein::Damerau::PP::pp_edistance",
-        rate        => 79000,
-        samples     => 33,
-        time        => 13,
-        vs_slowest  => 4.5,
+        rate        => 71800,
+        samples     => 25,
+        time        => 13.9,
+        vs_slowest  => 3.59,
       },
       {
         dataset     => "a",
-        errors      => 1e-10,
+        errors      => 6.7e-09,
         participant => "Text::Levenshtein::Damerau::PP::pp_edistance",
-        rate        => 241100,
+        rate        => 220000,
+        samples     => 20,
+        time        => 4.6,
+        vs_slowest  => 11,
+      },
+      {
+        dataset     => "euro",
+        errors      => 3.3e-09,
+        participant => "Text::Fuzzy",
+        rate        => 450000,
+        samples     => 20,
+        time        => 2.2,
+        vs_slowest  => 23,
+      },
+      {
+        dataset     => "program",
+        errors      => 5.6e-11,
+        participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
+        rate        => 471800,
         samples     => 22,
-        time        => 4.148,
-        vs_slowest  => 13.8,
-      },
-      {
-        dataset     => "euro",
-        errors      => 2.5e-09,
-        participant => "Text::Fuzzy",
-        rate        => 420000,
-        samples     => 20,
-        time        => 2.4,
-        vs_slowest  => 24,
+        time        => 2.119,
+        vs_slowest  => 23.61,
       },
       {
         dataset     => "program",
-        errors      => 8.3e-10,
+        errors      => 6.4e-09,
+        participant => "Text::Fuzzy",
+        rate        => 560000,
+        samples     => 22,
+        time        => 1.8,
+        vs_slowest  => 28,
+      },
+      {
+        dataset     => "reve",
+        errors      => 1.2e-11,
         participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
-        rate        => 477000,
+        rate        => 628900,
         samples     => 20,
-        time        => 2.1,
-        vs_slowest  => 27.3,
+        time        => 1.5901,
+        vs_slowest  => 31.474,
       },
       {
         dataset     => "euro",
-        errors      => 2.4e-08,
+        errors      => 4.2e-10,
         participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
-        rate        => 500000,
+        rate        => 678000,
         samples     => 20,
-        time        => 2,
-        vs_slowest  => 30,
-      },
-      {
-        dataset     => "program",
-        errors      => 2.8e-09,
-        participant => "Text::Fuzzy",
-        rate        => 620000,
-        samples     => 29,
-        time        => 1.6,
-        vs_slowest  => 36,
+        time        => 1.48,
+        vs_slowest  => 33.9,
       },
       {
         dataset     => "reve",
-        errors      => 6.8e-10,
-        participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
-        rate        => 626000,
-        samples     => 30,
-        time        => 1.6,
-        vs_slowest  => 35.8,
-      },
-      {
-        dataset     => "reve",
-        errors      => 5.4e-09,
+        errors      => 3.6e-10,
         participant => "Text::Fuzzy",
-        rate        => 680000,
-        samples     => 20,
-        time        => 1.5,
-        vs_slowest  => 39,
+        rate        => 729000,
+        samples     => 27,
+        time        => 1.37,
+        vs_slowest  => 36.5,
       },
       {
         dataset     => "foo",
-        errors      => 4.6e-11,
-        participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
-        rate        => 695700,
-        samples     => 20,
-        time        => 1.437,
-        vs_slowest  => 39.82,
+        errors      => 3.5e-10,
+        participant => "Text::Fuzzy",
+        rate        => 775000,
+        samples     => 28,
+        time        => 1.29,
+        vs_slowest  => 38.8,
       },
       {
         dataset     => "foo",
-        errors      => 9.4e-12,
-        participant => "Text::Fuzzy",
-        rate        => 791880,
-        samples     => 37,
-        time        => 1.2628,
-        vs_slowest  => 45.324,
-      },
-      {
-        dataset     => "a",
-        errors      => 9.6e-12,
+        errors      => 4.5e-10,
         participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
-        rate        => 991090,
-        samples     => 20,
-        time        => 1.009,
-        vs_slowest  => 56.726,
+        rate        => 780000,
+        samples     => 21,
+        time        => 1.28,
+        vs_slowest  => 39.1,
       },
       {
         dataset     => "a",
-        errors      => 1.7e-09,
+        errors      => 3.3e-09,
         participant => "Text::Fuzzy",
+        rate        => 900000,
+        samples     => 20,
+        time        => 1.1,
+        vs_slowest  => 45,
+      },
+      {
+        dataset     => "a",
+        errors      => 1.5e-09,
+        participant => "Text::Levenshtein::Damerau::XS::xs_edistance",
         rate        => 1000000,
-        samples     => 20,
-        time        => 1,
-        vs_slowest  => 57,
+        samples     => 25,
+        time        => 0.96,
+        vs_slowest  => 52,
       },
     ],
     {
@@ -263,7 +263,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2673.289,
+                                              speed                        => 2699.375,
                                               stepping                     => 4,
                                             },
                                             {
@@ -378,7 +378,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2858.351,
+                                              speed                        => 2791.195,
                                               stepping                     => 4,
                                             },
                                             {
@@ -493,7 +493,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2829.476,
+                                              speed                        => 2790.812,
                                               stepping                     => 4,
                                             },
                                             {
@@ -608,13 +608,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2721.523,
+                                              speed                        => 2689.695,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.417634010314941,
+      "func.elapsed_time"              => 0.363024950027466,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::DamerauLevenshteinModules" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -655,9 +656,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1484299732,
       "func.scenario_module_sha1sum"   => "54d67ec303ab397912a4a53e91f6b1089d1b548b",
       "func.scenario_module_sha256sum" => "1ff371099cca26f5debbbfc2d734175e68f420bc460b628845f35f7b8b9de389",
-      "func.time_end"                  => 1484299811.87181,
+      "func.time_end"                  => 1485330938.3236,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1484299811.45418,
+      "func.time_start"                => 1485330937.96057,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
