@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LevenshteinModules;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -9,237 +9,237 @@ our $results = [
     [
       {
         dataset     => "program",
-        errors      => 1.1e-07,
+        errors      => 5.6e-07,
         participant => "Text::Levenshtein::fastdistance",
-        rate        => 13000,
+        rate        => 14000,
         samples     => 20,
-        time        => 77,
+        time        => 73,
         vs_slowest  => 1,
       },
       {
         dataset     => "program",
-        errors      => 1.6e-07,
+        errors      => 1.1e-08,
         participant => "PERLANCAR::Text::Levenshtein::editdist",
-        rate        => 25000,
-        samples     => 20,
-        time        => 41,
-        vs_slowest  => 1.9,
+        rate        => 28100,
+        samples     => 28,
+        time        => 35.5,
+        vs_slowest  => 2.06,
       },
       {
         dataset     => "reve",
-        errors      => 5.3e-08,
+        errors      => 1.1e-07,
         participant => "Text::Levenshtein::fastdistance",
         rate        => 34000,
         samples     => 20,
         time        => 30,
-        vs_slowest  => 2.6,
+        vs_slowest  => 2.5,
       },
       {
         dataset     => "euro",
-        errors      => 2.6e-08,
+        errors      => 5e-08,
         participant => "Text::Levenshtein::fastdistance",
-        rate        => 40000,
-        samples     => 21,
+        rate        => 39000,
+        samples     => 23,
         time        => 25,
-        vs_slowest  => 3,
+        vs_slowest  => 2.9,
       },
       {
         dataset     => "foo",
-        errors      => 2.5e-08,
+        errors      => 2.7e-08,
         participant => "Text::Levenshtein::fastdistance",
-        rate        => 64000,
-        samples     => 22,
-        time        => 16,
-        vs_slowest  => 4.9,
+        rate        => 70000,
+        samples     => 20,
+        time        => 14,
+        vs_slowest  => 5.1,
       },
       {
         dataset     => "foo",
-        errors      => 3.3e-09,
+        errors      => 1.3e-08,
         participant => "PERLANCAR::Text::Levenshtein::editdist",
         rate        => 110000,
         samples     => 20,
-        time        => 9.13,
-        vs_slowest  => 8.41,
+        time        => 9.2,
+        vs_slowest  => 7.9,
       },
       {
         dataset     => "a",
-        errors      => 6.7e-09,
+        errors      => 8.3e-09,
         participant => "Text::Levenshtein::fastdistance",
-        rate        => 210000,
+        rate        => 230000,
         samples     => 20,
-        time        => 4.8,
-        vs_slowest  => 16,
+        time        => 4.4,
+        vs_slowest  => 17,
       },
       {
         dataset     => "a",
-        errors      => 7.3e-10,
+        errors      => 2.6e-09,
         participant => "PERLANCAR::Text::Levenshtein::editdist",
-        rate        => 362000,
-        samples     => 26,
-        time        => 2.76,
-        vs_slowest  => 27.8,
+        rate        => 400000,
+        samples     => 20,
+        time        => 2.5,
+        vs_slowest  => 30,
       },
       {
         dataset     => "program",
-        errors      => 2.5e-09,
+        errors      => 8.1e-10,
         participant => "Text::Levenshtein::XS::distance",
-        rate        => 520000,
-        samples     => 20,
-        time        => 1.9,
-        vs_slowest  => 40,
+        rate        => 513000,
+        samples     => 21,
+        time        => 1.95,
+        vs_slowest  => 37.6,
       },
       {
         dataset     => "euro",
         errors      => 3.3e-09,
         participant => "Text::Fuzzy",
-        rate        => 550000,
+        rate        => 600000,
         samples     => 20,
-        time        => 1.8,
-        vs_slowest  => 42,
+        time        => 1.7,
+        vs_slowest  => 44,
       },
       {
         dataset     => "reve",
+        errors      => 1.5e-10,
+        participant => "Text::Levenshtein::XS::distance",
+        rate        => 656000,
+        samples     => 31,
+        time        => 1.52,
+        vs_slowest  => 48.1,
+      },
+      {
+        dataset     => "euro",
         errors      => 1.7e-09,
         participant => "Text::Levenshtein::XS::distance",
-        rate        => 670000,
+        rate        => 700000,
         samples     => 20,
-        time        => 1.5,
+        time        => 1.4,
         vs_slowest  => 51,
       },
-      {
-        dataset     => "euro",
-        errors      => 8.1e-09,
-        participant => "Text::Levenshtein::XS::distance",
-        rate        => 680000,
-        samples     => 33,
-        time        => 1.5,
-        vs_slowest  => 52,
-      },
       {
         dataset     => "foo",
-        errors      => 4.5e-11,
+        errors      => 1.1e-11,
         participant => "Text::Levenshtein::XS::distance",
-        rate        => 820100,
-        samples     => 20,
-        time        => 1.219,
-        vs_slowest  => 62.92,
+        rate        => 789220,
+        samples     => 24,
+        time        => 1.2671,
+        vs_slowest  => 57.804,
       },
       {
         dataset     => "program",
-        errors      => 9.1e-12,
-        participant => "Text::Fuzzy",
-        rate        => 907230,
-        samples     => 20,
-        time        => 1.1023,
-        vs_slowest  => 69.602,
-      },
-      {
-        dataset     => "reve",
-        errors      => 4.6e-11,
-        participant => "Text::Fuzzy",
-        rate        => 991300,
-        samples     => 20,
-        time        => 1.009,
-        vs_slowest  => 76.05,
-      },
-      {
-        dataset     => "foo",
-        errors      => 1.1e-10,
-        participant => "Text::Fuzzy",
-        rate        => 1050000,
-        samples     => 22,
-        time        => 0.95,
-        vs_slowest  => 80.8,
-      },
-      {
-        dataset     => "a",
-        errors      => 1.3e-09,
-        participant => "Text::Levenshtein::XS::distance",
-        rate        => 1100000,
-        samples     => 33,
-        time        => 0.93,
-        vs_slowest  => 82,
-      },
-      {
-        dataset     => "a",
         errors      => 1.7e-09,
         participant => "Text::Fuzzy",
-        rate        => 1100000,
+        rate        => 990000,
         samples     => 20,
-        time        => 0.92,
-        vs_slowest  => 83,
+        time        => 1,
+        vs_slowest  => 72,
       },
       {
-        dataset     => "program",
-        errors      => 1.9e-10,
-        participant => "Text::LevenshteinXS::distance",
-        rate        => 3040000,
-        samples     => 27,
-        time        => 0.329,
-        vs_slowest  => 233,
-      },
-      {
-        dataset     => "program",
-        errors      => 3.5e-11,
-        participant => "Text::Levenshtein::Flexible::levenshtein",
-        rate        => 4380000,
+        dataset     => "a",
+        errors      => 4.1e-10,
+        participant => "Text::Levenshtein::XS::distance",
+        rate        => 1010000,
         samples     => 21,
-        time        => 0.228,
-        vs_slowest  => 336,
-      },
-      {
-        dataset     => "euro",
-        errors      => 1.4e-09,
-        participant => "Text::Levenshtein::Flexible::levenshtein",
-        rate        => 4900000,
-        samples     => 20,
-        time        => 0.2,
-        vs_slowest  => 380,
+        time        => 0.993,
+        vs_slowest  => 73.7,
       },
       {
         dataset     => "reve",
-        errors      => 1.1e-10,
+        errors      => 3.2e-10,
+        participant => "Text::Fuzzy",
+        rate        => 1090000,
+        samples     => 34,
+        time        => 0.914,
+        vs_slowest  => 80.2,
+      },
+      {
+        dataset     => "foo",
+        errors      => 4.1e-10,
+        participant => "Text::Fuzzy",
+        rate        => 1140000,
+        samples     => 21,
+        time        => 0.879,
+        vs_slowest  => 83.3,
+      },
+      {
+        dataset     => "a",
+        errors      => 1.6e-09,
+        participant => "Text::Fuzzy",
+        rate        => 1200000,
+        samples     => 21,
+        time        => 0.83,
+        vs_slowest  => 88,
+      },
+      {
+        dataset     => "program",
+        errors      => 1e-10,
+        participant => "Text::LevenshteinXS::distance",
+        rate        => 3680000,
+        samples     => 21,
+        time        => 0.271,
+        vs_slowest  => 270,
+      },
+      {
+        dataset     => "program",
+        errors      => 1e-10,
         participant => "Text::Levenshtein::Flexible::levenshtein",
-        rate        => 6420000,
+        rate        => 4850000,
         samples     => 20,
-        time        => 0.156,
-        vs_slowest  => 492,
+        time        => 0.206,
+        vs_slowest  => 355,
+      },
+      {
+        dataset     => "euro",
+        errors      => 0,
+        participant => "Text::Levenshtein::Flexible::levenshtein",
+        rate        => 5175710,
+        samples     => 20,
+        time        => 0.19321,
+        vs_slowest  => 379.081,
+      },
+      {
+        dataset     => "reve",
+        errors      => 0,
+        participant => "Text::Levenshtein::Flexible::levenshtein",
+        rate        => 7051530,
+        samples     => 24,
+        time        => 0.141813,
+        vs_slowest  => 516.47,
       },
       {
         dataset     => "foo",
         errors      => 2.1e-10,
-        participant => "Text::Levenshtein::Flexible::levenshtein",
-        rate        => 7900000,
+        participant => "Text::LevenshteinXS::distance",
+        rate        => 8400000,
         samples     => 20,
-        time        => 0.13,
-        vs_slowest  => 600,
+        time        => 0.12,
+        vs_slowest  => 610,
       },
       {
         dataset     => "foo",
-        errors      => 7.1e-11,
-        participant => "Text::LevenshteinXS::distance",
-        rate        => 8300000,
-        samples     => 20,
-        time        => 0.12,
-        vs_slowest  => 637,
-      },
-      {
-        dataset     => "a",
-        errors      => 6.5e-11,
+        errors      => 9.8e-12,
         participant => "Text::Levenshtein::Flexible::levenshtein",
-        rate        => 9320000,
-        samples     => 25,
-        time        => 0.107,
-        vs_slowest  => 715,
+        rate        => 8600000,
+        samples     => 22,
+        time        => 0.1163,
+        vs_slowest  => 629.9,
       },
       {
         dataset     => "a",
-        errors      => 4.8e-11,
+        errors      => 5.1e-11,
         participant => "Text::LevenshteinXS::distance",
-        rate        => 11000000,
-        samples     => 31,
-        time        => 0.0909,
-        vs_slowest  => 844,
+        rate        => 10000000,
+        samples     => 21,
+        time        => 0.0998,
+        vs_slowest  => 734,
+      },
+      {
+        dataset     => "a",
+        errors      => 5.3e-11,
+        participant => "Text::Levenshtein::Flexible::levenshtein",
+        rate        => 10000000,
+        samples     => 20,
+        time        => 0.0997,
+        vs_slowest  => 735,
       },
     ],
     {
@@ -362,7 +362,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2732.843,
+                                              speed                        => "2753.460",
                                               stepping                     => 4,
                                             },
                                             {
@@ -477,7 +477,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2645.070",
+                                              speed                        => 2653.218,
                                               stepping                     => 4,
                                             },
                                             {
@@ -592,7 +592,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2686.414,
+                                              speed                        => 2645.507,
                                               stepping                     => 4,
                                             },
                                             {
@@ -707,13 +707,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2699.921,
+                                              speed                        => "2632.000",
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.66010594367981,
+      "func.elapsed_time"              => 0.6281578540802,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__"                           => 1.034,
                                             "Bencher::Scenario::LevenshteinModules" => undef,
                                             "Benchmark::Dumb"                       => "0.10",
                                             "Devel::Platform::Info"                 => 0.16,
@@ -757,9 +758,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1484299562,
       "func.scenario_module_sha1sum"   => "a5b237afecb6b58545015f18310a2cab9a02fa7f",
       "func.scenario_module_sha256sum" => "58f4ad0b4ea547d92378b7aff8fe893fe660c3d3bbf17366df7d0c5fcda22b48",
-      "func.time_end"                  => 1484299813.93189,
+      "func.time_end"                  => 1485330940.27668,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1484299813.27179,
+      "func.time_start"                => 1485330939.64852,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
